function o_Quadropod = open_Quadropods(R,RP,wordlength)

    %%%compute all open quadropods. They are of the form:
    %%%[rp1, rp2,0,0] where rp1 and rp2 are rectangle pairs. 
    %%%if rp1 = [r11,s12,r12,s12] and rp2 =  [r21,s22,r22,s22];
    
    %%%%A rectangle pair [r1,s1,r2,s2] has the flip =-[r2,s2,r1,s1].
    %%%%We say that this information forms a rectangle pair if
    %%%%- after flipping the rectangles themselves, we have that r12 is
    %%%%followed by r21 and r22 is followed by r11.
    
    o_Quadropod = [0,0,0,0];
    
    s_l_rp = size(RP);
    Number_RP = s_l_rp(1);
    s_l_rect = size(R);
    Number_R = s_l_rect(1);
    for rp1=1:Number_RP
        for sign_rp1 = -1:2:1
            %%%choose the sign for the rectangle pair 1
            
            if sign_rp1 == -1
                rp_1_temp = rectangle_pair_flip(RP(rp1,:));
            else 
                rp_1_temp = RP(rp1,:);
            end
            
        for rp2=rp1:Number_RP
        for sign_rp2 = -1:2:1
            %%%choose the sign for the rectangle pair 2
            
            if sign_rp2 == -1
                rp_2_temp = rectangle_pair_flip(RP(rp2,:));
            else 
                rp_2_temp = RP(rp2,:);
            end
            
            %%%read off the information of rectangle pair 1
            rp_1_r1 = R(rp_1_temp(1),:);
            rp_1_s1 = rp_1_temp(2);
            rp_1_r2 = R(rp_1_temp(3),:);
            rp_1_s2 = rp_1_temp(4);            
            %%%read off the information of rectangle pair 2
            rp_2_r1 = R(rp_2_temp(1),:);
            rp_2_s1 = rp_2_temp(2);
            rp_2_r2 = R(rp_2_temp(3),:);
            rp_2_s2 = rp_2_temp(4);
            
            %%%%check conditions
            if following_rectangle(rp_1_r2,rp_1_s2,rp_2_r1,rp_2_s1, wordlength)==1
                if following_rectangle(rp_2_r2,rp_2_s2,rp_1_r1,rp_1_s1, wordlength)==1
                    o_Quadropod = [o_Quadropod; sign_rp1*rp1, sign_rp2*rp2,0,0];
                end
            end
            end
        end
    end
    end
o_Quadropod = o_Quadropod(2:end,:);
end





function r_pair_flip = rectangle_pair_flip(r_pair)

r_pair_flip(1) = r_pair(3);
r_pair_flip(2) = r_pair(4);
r_pair_flip(3) = r_pair(1);
r_pair_flip(4) = r_pair(2);
end